(wrap-single-list f)wraps normalise with support for more complex expressions through use of double vector
(pipeline/normalise {:account {:age '(< ? 1)}} {:schema (schema/schema {:account/age [{:type :long}]})} {:normalise-single [wrap-single-list]}) => {:account {:age '(< ? 1)}}
wraps normalise with support for more complex expressions through use of double vector
(pipeline/normalise {:account {:age '(< ? 1)}}
{:schema (schema/schema {:account/age [{:type :long}]})}
{:normalise-single [wrap-single-list]})
=> {:account {:age '(< ? 1)}}cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |